==> common-2.0.0-sources.jar: cn/gtmap/gtc/resource/domain/resource/dto/es/DataResourceIdxDTO.java <==
package cn.gtmap.gtc.resource.domain.resource.dto.es;

import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:yangyang@gtmap.cn">yangyang</a>
 * @version 1.0.2020-4-8
 * @description
 */


public class DataResourceIdxDTO implements Serializable {
    private String url;
    private String authToken;
    private String title;
    private String type;
    //authentication 认证    apply 申请
    private String operation;
    private String dataId;
    private String capable;
    private String result;
    private String message;
    private String principal;
    private String userAlias;
    private String orgName;
    private String orgCode;
    private String roleName;
    private String roleAlias;
    private Date timestamp;

    public String getUrl() {
        return url;
    }

    public DataResourceIdxDTO setUrl(String url) {
        this.url = url;
        return this;
    }

    public String getAuthToken() {
        return authToken;
    }

    public DataResourceIdxDTO setAuthToken(String authToken) {
        this.authToken = authToken;
        return this;
    }

    public String getType() {
        return type;
    }

    public DataResourceIdxDTO setType(String type) {
        this.type = type;
        return this;
    }

    public String getDataId() {
        return dataId;
    }

    public DataResourceIdxDTO setDataId(String dataId) {
        this.dataId = dataId;
        return this;
    }

    public String getCapable() {
        return capable;
    }

    public DataResourceIdxDTO setCapable(String capable) {
        this.capable = capable;
        return this;
    }

    public String getResult() {
        return result;
    }

    public DataResourceIdxDTO setResult(String result) {
        this.result = result;
        return this;
    }

    public String getMessage() {
        return message;
    }

    public DataResourceIdxDTO setMessage(String message) {
        this.message = message;
        return this;
    }

    public String getPrincipal() {
        return principal;
    }

    public DataResourceIdxDTO setPrincipal(String principal) {
        this.principal = principal;
        return this;
    }

    public String getUserAlias() {
        return userAlias;
    }

    public DataResourceIdxDTO setUserAlias(String userAlias) {
        this.userAlias = userAlias;
        return this;
    }

    public String getOrgName() {
        return orgName;
    }

    public DataResourceIdxDTO setOrgName(String orgName) {
        this.orgName = orgName;
        return this;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public DataResourceIdxDTO setOrgCode(String orgCode) {
        this.orgCode = orgCode;
        return this;
    }

    public String getRoleName() {
        return roleName;
    }

    public DataResourceIdxDTO setRoleName(String roleName) {
        this.roleName = roleName;
        return this;
    }

    public String getRoleAlias() {
        return roleAlias;
    }

    public DataResourceIdxDTO setRoleAlias(String roleAlias) {
        this.roleAlias = roleAlias;
        return this;
    }

    public Date getTimestamp() {
        return timestamp;
    }

    public DataResourceIdxDTO setTimestamp(Date timestamp) {
        this.timestamp = timestamp;
        return this;
    }

    public String getTitle() {
        return title;
    }

    public DataResourceIdxDTO setTitle(String title) {
        this.title = title;
        return this;
    }

    public String getOperation() {
        return operation;
    }

    public DataResourceIdxDTO setOperation(String operation) {
        this.operation = operation;
        return this;
    }
}

==> common-2.0.2-sources.jar: cn/gtmap/gtc/resource/domain/resource/dto/es/DataResourceIdxDTO.java <==
package cn.gtmap.gtc.resource.domain.resource.dto.es;

import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:yangyang@gtmap.cn">yangyang</a>
 * @version 1.0.2020-4-8
 * @description
 */


public class DataResourceIdxDTO implements Serializable {
    private String url;
    private String authToken;
    private String title;
    /**
     * 业务类型，如“数据下载”等
     */
    private String type;
    /**
     * 业务描述
     * authentication 认证    apply 申请
     */
    private String operation;
    /**
     * 资源id
     */
    private String dataId;
    private String capable;
    private String result;
    private String message;
    private String principal;
    private String userAlias;
    private String userId;
    private String orgName;
    private String orgCode;
    private String roleName;
    private String roleAlias;
    private Date timestamp;

    public String getUrl() {
        return url;
    }

    public DataResourceIdxDTO setUrl(String url) {
        this.url = url;
        return this;
    }

    public String getUserId() {
        return userId;
    }

    public DataResourceIdxDTO setUserId(String userId) {
        this.userId = userId;
        return this;
    }

    public String getAuthToken() {
        return authToken;
    }

    public DataResourceIdxDTO setAuthToken(String authToken) {
        this.authToken = authToken;
        return this;
    }

    public String getType() {
        return type;
    }

    public DataResourceIdxDTO setType(String type) {
        this.type = type;
        return this;
    }

    public String getDataId() {
        return dataId;
    }

    public DataResourceIdxDTO setDataId(String dataId) {
        this.dataId = dataId;
        return this;
    }

    public String getCapable() {
        return capable;
    }

    public DataResourceIdxDTO setCapable(String capable) {
        this.capable = capable;
        return this;
    }

    public String getResult() {
        return result;
    }

    public DataResourceIdxDTO setResult(String result) {
        this.result = result;
        return this;
    }

    public String getMessage() {
        return message;
    }

    public DataResourceIdxDTO setMessage(String message) {
        this.message = message;
        return this;
    }

    public String getPrincipal() {
        return principal;
    }

    public DataResourceIdxDTO setPrincipal(String principal) {
        this.principal = principal;
        return this;
    }

    public String getUserAlias() {
        return userAlias;
    }

    public DataResourceIdxDTO setUserAlias(String userAlias) {
        this.userAlias = userAlias;
        return this;
    }

    public String getOrgName() {
        return orgName;
    }

    public DataResourceIdxDTO setOrgName(String orgName) {
        this.orgName = orgName;
        return this;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public DataResourceIdxDTO setOrgCode(String orgCode) {
        this.orgCode = orgCode;
        return this;
    }

    public String getRoleName() {
        return roleName;
    }

    public DataResourceIdxDTO setRoleName(String roleName) {
        this.roleName = roleName;
        return this;
    }

    public String getRoleAlias() {
        return roleAlias;
    }

    public DataResourceIdxDTO setRoleAlias(String roleAlias) {
        this.roleAlias = roleAlias;
        return this;
    }

    public Date getTimestamp() {
        return timestamp;
    }

    public DataResourceIdxDTO setTimestamp(Date timestamp) {
        this.timestamp = timestamp;
        return this;
    }

    public String getTitle() {
        return title;
    }

    public DataResourceIdxDTO setTitle(String title) {
        this.title = title;
        return this;
    }

    public String getOperation() {
        return operation;
    }

    public DataResourceIdxDTO setOperation(String operation) {
        this.operation = operation;
        return this;
    }
}
